@@ -1,7 +1,5 @@
 from functools import partial
 from operator import attrgetter
-from toolz import curry, first
-import six
 import sqlalchemy as sa
 from sqlalchemy import inspect
 from sqlalchemy.orm.attributes import InstrumentedAttribute
@@ -10,24 +8,6 @@ from sqlalchemy.orm.mapper import Mapper
 from sqlalchemy.orm.util import AliasedInsp
 
 
-def remove_property(class_, name):
-    """
-    **Experimental function**
-
-    Remove property from declarative class
-    """
-    mapper = class_.mapper
-    table = class_.__table__
-    columns = class_.mapper.c
-    column = columns[name]
-    del columns._data[name]
-    del mapper.columns[name]
-    columns._all_cols.remove(column)
-    mapper._cols_by_table[table].remove(column)
-    mapper.class_manager.uninstrument_attribute(name)
-    del mapper._props[name]
-
-
 def primary_keys(class_):
     """
     Returns all primary keys for given declarative class.
@@ -59,24 +39,18 @@ def getattrs(obj, attrs):
     return map(partial(getattr, obj), attrs)
 
 
-def mapfirst(iterable):
-    return map(first, iterable)
-
-
-@curry
 def local_values(prop, entity):
     return tuple(getattrs(entity, local_column_names(prop)))
 
 
 def list_local_values(prop, entities):
-    return map(local_values(prop), entities)
+    return map(partial(local_values, prop), entities)
 
 
 def remote_values(prop, entity):
     return tuple(getattrs(entity, remote_column_names(prop)))
 
 
-@curry
 def local_remote_expr(prop, entity):
     return sa.and_(
         *[
@@ -90,7 +64,7 @@ def local_remote_expr(prop, entity):
 
 
 def list_local_remote_exprs(prop, entities):
-    return map(local_remote_expr(prop), entities)
+    return map(partial(local_remote_expr, prop), entities)
 
 
 def remote(prop):
@@ -129,7 +103,6 @@ def remote_column_names(prop):
                     yield remote.name
 
 
-
 def query_labels(query):
     """
     Return all labels for given SQLAlchemy query object.
@@ -179,7 +152,7 @@ def query_entities(query):
 def get_query_entity_by_alias(query, alias):
     entities = query_entities(query)
     if not alias:
-        return first(entities)
+        return list(entities)[0]
 
     for entity in entities:
         if isinstance(entity, AliasedInsp):
